#
# spec file for package python-CacheControl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-CacheControl
Version:        0.14.3
Release:        1.1
Summary:        Caching library for Python requests
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/psf/cachecontrol
Source:         https://github.com/psf/cachecontrol/archive/v%{version}.tar.gz#/cachecontrol-%{version}.tar.gz
BuildRequires:  %{python_module flit-core >= 3.11}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-msgpack >= 0.5.2
Requires:       python-requests >= 2.16.0
Provides:       python-cachecontrol = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-filelock >= 3.8.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module CherryPy}
BuildRequires:  %{python_module filelock >= 3.8.0}
BuildRequires:  %{python_module msgpack >= 0.5.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.16.0}
# /SECTION
%python_subpackages

%description
CacheControl is a port of the caching algorithms in httplib2 for use with
requests session object.

%prep
%autosetup -p1 -n cachecontrol-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

# do not pack tests
%python_expand rm -rf %{buildroot}%{$python_sitelib}/tests

%python_clone -a %{buildroot}%{_bindir}/doesitcache
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_file_cache_recognizes_consumed_file_handle uses httpbin.org directly
%pytest -v -k 'not test_file_cache_recognizes_consumed_file_handle'

%post
%python_install_alternative doesitcache

%postun
%python_uninstall_alternative doesitcache

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%python_alternative %{_bindir}/doesitcache
%{python_sitelib}/cachecontrol
%{python_sitelib}/cachecontrol-%{version}*-info

%changelog
* Tue May  6 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.14.3
  * Drop support for Python 3.8.
- Update BuildRequires from pyproject.toml
* Thu Jan 23 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.14.2
  * Eliminate a race condition when overwriting cache entries.
  * Fix a requests object leak when doing caching on a streamed
    response.
* Sun Nov 10 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.1:
  * Drop support for Python 3.8.
  * Explicitly support Python 3.13.
* Sat Feb  3 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.0:
  * Explicitly allow pathlib.Path as a type for
    FileCache.directory.
  * Drop support for Python 3.7. Python 3.8 is now the minimum
    version.
  * Don't use the cache to return a full response if a request
    has a Range header.
* Fri Dec 29 2023 Antonio Larrosa <alarrosa@suse.com>
- Remove BuildRequires and Suggests python-redis since it's not
  really used when building and there's no reason to suggest it
  unless someone wants to explicitly use redis, this simplifies
  the dependencies which is useful for SLE.
* Mon Jun 19 2023 Torsten Gruner <simmphonie@opensuse.org>
- Update to v0.13.1
  * Support for old serialization formats has been removed.
  * Move the serialization implementation into own method.
  * Drop support for Python older than 3.7.
- version 0.13.0
  * YANKED
  * The project has been moved to the PSF organization.
  * Discard the strict attribute when serializing and deserializing responses.
  * Fix the IncompleteRead error thrown by urllib3 2.0.
  * Remove usage of utcnow in favor of timezone-aware datetimes.
  * Remove the compat module.
  * Use Python's unittest.mock library instead of mock.
  * Add type annotations.
  * Exclude the tests directory from the wheel.
- version 0.12.14
  * Revert the change "switch lockfile to filelock" to fix the compatibility issue.
- version 0.12.13
  * Discard the strict attribute when serializing and deserializing responses.
  * Fix the IncompleteRead error thrown by urllib3 2.0.
  * Exclude the tests directory from the wheel.
- Remove requests-fix.patch (obsolete)
* Tue May 30 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add requests-fix.patch to support latest version of urllib3 and
  requests
  gh#ionrock/cachecontrol#301, gh#ionrock/cachecontrol#304
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Aug  2 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to v0.12.11
  * Added new variant of FileCache, SeparateBodyFileCache, which uses
    less memory by storing the body in a separate file than metadata,
    and streaming data in and out directly to/from that file.
* Sat Dec  4 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.12.10
  * Dropped support for Python 2.7, 3.4, 3.5.
  * Reduced memory usage when caching large files.
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Jan  2 2020 John Vandenberg <jayvdb@gmail.com>
- Drop merged pytest4.patch
- Add explanation of one test failure
- Remove mention of httplib2 from package summary
- Update to v0.12.6
  * Test if cache is None before falling back to DictCache
  * Fixed body in 304 response to etag request
  * Added check for "*" value in Vary header
  * Make v4 cache compatible with msgpack 1.0 in the future
* Fri Nov  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with new pytest:
  * pytest4.patch
* Wed Sep 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Restrict pytest to 3.x as newer released do not work with
  this package
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run tests only under py3 as CherryPy is available only there
* Mon Mar 25 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, with two tests currently failing
- Trim description, removing irrelevant information about httplib2
- Recommend lockfile, as a lightweight dependency needed for FileCache,
  which is a primary use of CacheControl.
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.5:
  * various test fixes
  * few crasher fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Mar 23 2018 tbechtold@suse.com
- Initial packaging (version 0.12.4)
